Model

Struct Model 

pub struct Model {
    pub id: i32,
    pub conversation_id: i32,
    pub kind: String,
    pub content: String,
    pub created_at: String,
    pub delivered_at: Option<i64>,
}

Fields

id: i32conversation_id: i32kind: Stringcontent: Stringcreated_at: Stringdelivered_at: Option<i64>

Unix epoch timestamp set when all registered gateways have delivered this event. NULL means delivery is still pending for at least one gateway.

Implementations

Source

impl Model

pub async fn insert( db: &DatabaseConnection, conversation_id: i32, kind: &str, content: &str, ) -> Result<()>

pub async fn find_undelivered(db: &DatabaseConnection) -> Result<Vec<Model>>

Returns all process_events where delivered_at IS NULL (not yet fully delivered).

pub async fn mark_delivered(db: &DatabaseConnection, id: i32) -> Result<()>

Marks a process_event as fully delivered (all gateways done) using current Unix epoch.

pub async fn find_by_conversation( db: &DatabaseConnection, conversation_id: i32, ) -> Result<Vec<Model>>